﻿/* Information
----------------------------------------------
File Name : jquery.twitter2.js
URL : http://www.atokala.com/
Copyright : (C)atokala
Author : Masahiro Abe
--------------------------------------------*/
(function($){
	$.fn.ATTwitter2 = function(config) {

		var defaults = {
			tweets : '.attweets',
			count : 10
		}

		var options = $.extend(defaults, config);

		return this.each(function(){
			var _self = $(this);

			function twitterLoad(json) {
				var twitterContents = '';
				for (var i = 0; i < json.length; i++) {
					twitterContents += tweetHTML(json[i]);
				}
				$(options.tweets, _self).append(twitterContents);
			}

			// ツイート一件分作成
			function tweetHTML(jsonData) {
				var template = '';
				template += '<div class="attweet">';
				template += '<p class="atphoto"><a href="http://twitter.com/#!/' + jsonData.user.screen_name + '" target="_blank"><img src="' + jsonData.user.profile_image_url + '" /></a></p>';
				template += '<p class="attext">' + formatTwitterString(jsonData.text) + '</p>';
				template += '<p class="atstatus"><a href="https://twitter.com/#!/' + jsonData.user.screen_name + '/status/' + jsonData.id_str + '" target="_blank">' + elapsedDate(jsonData.created_at) + '</a>　' + jsonData.source + 'から</p>';
				template += '</div>';
				return template;
			}

			// リンク作成
			function formatTwitterString(str) {
				str = str.replace(/((ftp|http|https?):\/\/([-\w\.]+)+(:\d+)?(\/([\w/_\.]*(\?\S+)?)?)?)/gm,'<a href="$1" target="_blank">$1</a>');
				str = str.replace(/@(\w+)/gm,'<a href="http://twitter.com/$1" target="_blank">@$1</a>');

				var index = str.search('#');
				//ハッシュが先頭の場合
				if (index == 0) {
					str = str.replace(/#(\S+)/gm, function(all, hash) {
						var url = encodeURI(hash);
						return '<a href="http://twitter.com/search?q=%23' + url + '" target="_blank">#' + hash + '</a>';
					});
				}
				else {
					str = str.replace(/(\s)#(\S+)/gm, function(all, space, hash) {
						var url = encodeURI(hash);
						return space + '<a href="http://twitter.com/search?q=%23' + url + '" target="_blank">#' + hash + '</a>';
					});
				}
				return str;
			}

			// 時間の変換
			function elapsedDate(datetime) {
				var date1 = new Date(datetime.replace("+", "UTC+"));
				var date2 = new Date();
				var diff = date2 - date1;

				if (diff < 3600000) {
					if (diff < 0) {
						return '0分前';
					} else {
						return parseInt(diff / 60000) + '分前';
					}
				}
				else if (diff < 86400000) {
					return parseInt(diff / 3600000) + '時間前';
				}
				else if (diff > 2592000000) {
					return parseInt(diff / 2592000000) + 'ヶ月前';
				}
				else {
					return parseInt(diff / 86400000) + '日前';
				}
			}

			function setCallback(cbname) {
				// Set up the callback
				window[cbname] = function(data) {
					// Remove us from the window object
					try {
						delete window[cbname];
					}
					catch (e) { // Handle IE bug (throws an error when you try to delete window properties)
						window[cbname] = undefined;
					}

					// Runs the function
					twitterLoad(data);
				};
			}

			function getCallbackName() {
				var cbname = "atcallback_" + new Date().getTime() + "_" + Math.floor(Math.random() * 10000);
				return cbname;
			}

			function getTwitter(action) {
				var cbname = getCallbackName();
				setCallback(cbname);

				var accessor = {
					consumerSecret: options.consumerSecret,
					tokenSecret: options.tokenSecret
				};

				var message = {
					method: "GET",
					action: action,
					parameters: {
						count: options.count,
						oauth_version: "1.0",
						oauth_signature_method: "HMAC-SHA1",
						oauth_consumer_key: options.consumerKey,
						oauth_token: options.accessToken,
						screen_name: options.screen_name,
						callback: cbname
					}
				};

				OAuth.setTimestampAndNonce(message);
				OAuth.SignatureMethod.sign(message, accessor);
				var url = OAuth.addToURL(message.action, message.parameters);

				$.ajax({
					type: message.method,
					url: url,
					dataType: "jsonp",
					jsonp: false,
					cache: true
				});
			}

			getTwitter("https://api.twitter.com/1.1/statuses/user_timeline.json");
		});
	};
})(jQuery);
